@@ -118,18 +118,27 @@ class Jaal:
         graph_data = self.filtered_data
         return graph_data
 
-    def plot(self, debug=False, host="127.0.0.1", port="8050"):
+    def plot(self, debug=False, host="127.0.0.1", port="8050", directed=False):
         """Plot the network by running the Dash server 
 
         Parameter
         ----------
-        debug: boolean
-            run the debug instance of Dash?
+            debug (boolean)
+                run the debug instance of Dash?
+
+            host: string
+                ip address on which to run the dash server (default: 127.0.0.1)
+
+            port: string
+                port on which to expose the dash server (default: 8050)
+
+            directed: boolean
+                process the graph as directed graph?
         """
         # create the app
         app = dash.Dash(external_stylesheets=[dbc.themes.BOOTSTRAP])
         # # define layout
-        app.layout = get_app_layout(self.data)
+        app.layout = get_app_layout(self.data, directed=directed)
         # create the callbacks
         @app.callback(
             Output('graph', 'data'),
